@@ -16,10 +16,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- *
- * $LastChangedBy$
- * $LastChangedDate$
- * $LastChangedRevision$
  */
 
 #ifndef INSTALL_H
@@ -52,7 +48,7 @@ int install_mount (const char *what);
 int install_umount (const char *what);
 int install_umount_all (void);
 
-typedef int install_simulate_handler (const char *command);
+typedef int install_simulate_handler (const char *const command[]);
 
 int install_init (const char *helperdir, install_simulate_handler *simulate_handler);
 
