@@ -16,10 +16,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- *
- * $LastChangedBy$
- * $LastChangedDate$
- * $LastChangedRevision$
  */
 
 #include <config.h>
@@ -45,7 +41,7 @@ int decompress_file (const char *file, const char *extension)
 
   snprintf (buf, sizeof (buf), "gunzip -c %s.%s > %s", file, extension, file);
 
-  return execute (buf);
+  return execute_sh (buf);
 }
 
 static int download_file (const char *source, const char *target, const char *message)
