@@ -16,10 +16,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- *
- * $LastChangedBy$
- * $LastChangedDate$
- * $LastChangedRevision$
  */
 
 #define _GNU_SOURCE
@@ -137,7 +133,7 @@ int frontend_download (const char *source, const char *target)
       snprintf (buf, sizeof buf, "ssh -o BatchMode=yes %s 'cat %s/%s' > %s", mirror_host, mirror_path, source, target);
   }
 
-  ret = execute (buf);
+  ret = execute_sh (buf);
 
   return WEXITSTATUS (ret);
 }
@@ -207,13 +203,13 @@ static void check_mirror (const char *mirror)
   check_mirror_path (temp);
 }
 
-static void check_permission (void)
+static void check_permission (bool noexec)
 {
-  if (getuid ())
+  if (!noexec && getuid ())
     log_text (DI_LOG_LEVEL_ERROR, "Need root privileges");
 }
 
-static void check_target (const char *target)
+static void check_target (const char *target, bool noexec)
 {
   struct stat s;
   struct statvfs sv;
@@ -235,9 +231,9 @@ static void check_target (const char *target)
   {
     if (sv.f_flag & ST_RDONLY)
       log_text (DI_LOG_LEVEL_ERROR, "Target is readonly");
-    if (sv.f_flag & ST_NODEV)
+    if (sv.f_flag & ST_NODEV && !noexec)
       log_text (DI_LOG_LEVEL_ERROR, "Target disallows device special files");
-    if (sv.f_flag & ST_NOEXEC)
+    if (sv.f_flag & ST_NOEXEC && !noexec)
       log_text (DI_LOG_LEVEL_ERROR, "Target disallows program execution");
   }
   else
@@ -398,20 +394,19 @@ dpkg-divert --remove --local --rename --divert /sbin/init.REAL /sbin/init\n\
 rm /sbin/cdebootstrap-foreign\n\
 ", foreign_script);
 
-  snprintf (buf1, sizeof buf1, "%s/dev/console", target_root);
-
-  if (mknod (buf1, S_IFCHR | 0600, makedev (5, 1)) < 0)
-    log_text (DI_LOG_LEVEL_WARNING, "Creation of /dev/console failed");
-
   log_text (DI_LOG_LEVEL_INFO, "Second stage installer is available as /sbin/cdebootstrap-foreign or /sbin/init");
 
   return 0;
 }
 
 static install_simulate_handler foreign_handler;
-static int foreign_handler (const char *command)
+static int foreign_handler (const char *const command[])
 {
-  fputs (command, foreign_script);
+  for (; *command; command++)
+  {
+    fputs (*command, foreign_script);
+    fputs (" ", foreign_script);
+  }
   fputs ("\n", foreign_script);
   return 0;
 }
@@ -667,9 +662,8 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
   umask (022);
 
   check_mirror (mirror);
-  if (!download_only)
-    check_permission ();
-  check_target (target);
+  check_permission (download_only || foreign);
+  check_target (target, download_only || foreign);
 
   log_init ();
 
